"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var typedoc_1 = require("typedoc");
var enumerations_1 = require("./enumerations");
/**
 * Supported image output locations.
 */
var ImageLocation;
(function (ImageLocation) {
    ImageLocation[ImageLocation["Local"] = 1] = "Local";
    ImageLocation[ImageLocation["Remote"] = 2] = "Remote";
    ImageLocation[ImageLocation["Embed"] = 3] = "Embed";
})(ImageLocation = exports.ImageLocation || (exports.ImageLocation = {}));
/**
 * Supported class diagram positions.
 */
var ClassDiagramPosition;
(function (ClassDiagramPosition) {
    ClassDiagramPosition[ClassDiagramPosition["Above"] = 1] = "Above";
    ClassDiagramPosition[ClassDiagramPosition["Below"] = 2] = "Below";
})(ClassDiagramPosition = exports.ClassDiagramPosition || (exports.ClassDiagramPosition = {}));
/**
 * Class storing the options of the plugin.
 */
var PluginOptions = /** @class */ (function () {
    function PluginOptions() {
        /** Specifies how detailed the class diagrams should be. */
        this.umlClassDiagramTypeOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramType",
            help: "none|simple|detailed",
            defaultValue: enumerations_1.ClassDiagramType.Detailed,
            map: new Map([
                ["none", enumerations_1.ClassDiagramType.None],
                ["simple", enumerations_1.ClassDiagramType.Simple],
                ["detailed", enumerations_1.ClassDiagramType.Detailed],
            ]),
            value: enumerations_1.ClassDiagramType.Detailed,
        };
        /** The location where the class diagrams should be stored. */
        this.outputImageLocationOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramLocation",
            help: "local|remote|embed",
            defaultValue: ImageLocation.Local,
            map: new Map([
                ["local", ImageLocation.Local],
                ["remote", ImageLocation.Remote],
                ["embed", ImageLocation.Embed],
            ]),
            value: ImageLocation.Local,
        };
        /** The image format used for the class diagrams. */
        this.outputImageFormatOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramFormat",
            help: "png|svg",
            defaultValue: "svg" /* SVG */,
            map: new Map([
                ["png", "png" /* PNG */],
                ["svg", "svg" /* SVG */],
            ]),
            value: "svg" /* SVG */,
        };
        /** Specifies how method parameters should be output in the class diagrams. */
        this.umlClassDiagramMethodParameterOutputOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMethodParameterOutput",
            help: "none|only-names|only-types|complete",
            defaultValue: enumerations_1.MethodParameterOutput.Complete,
            map: new Map([
                ["none", enumerations_1.MethodParameterOutput.None],
                ["only-names", enumerations_1.MethodParameterOutput.OnlyNames],
                ["only-types", enumerations_1.MethodParameterOutput.OnlyTypes],
                ["complete", enumerations_1.MethodParameterOutput.Complete],
            ]),
            value: enumerations_1.MethodParameterOutput.Complete,
        };
        /** Specifies the background color used for boxes in the class diagrams. */
        this.umlClassDiagramSectionTitleOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramSectionTitle",
            help: "The title of the section on the page which includes the class diagram.",
            defaultValue: "Hierarchy-Diagram",
            value: "Hierarchy-Diagram",
        };
        /** Specifies where on the page the class diagram should be put. */
        this.umlClassDiagramPositionOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramPosition",
            help: "above|below",
            defaultValue: ClassDiagramPosition.Above,
            map: new Map([
                ["above", ClassDiagramPosition.Above],
                ["below", ClassDiagramPosition.Below],
            ]),
            value: ClassDiagramPosition.Above,
        };
        /** Specifies whether to hide empty properties and methods in the class diagrams. */
        this.umlClassDiagramHideEmptyMembersOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideEmptyMembers",
            help: "true|false",
            defaultValue: true,
            value: true,
        };
        /** Specifies the boundary before swiching from top->down to left->right direction for class diagrams. */
        this.umlClassDiagramTopDownLayoutMaxSiblingsOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramTopDownLayoutMaxSiblings",
            help: "An integer indicating the max number of siblings to be used with the default top down layout.",
            defaultValue: 6,
            minValue: 0,
            value: 6,
        };
        /** Specifies how the visibility of members should be displayed in the class diagrams. */
        this.umlClassDiagramMemberVisibilityStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMemberVisibilityStyle",
            help: "text|icon",
            defaultValue: enumerations_1.ClassDiagramMemberVisibilityStyle.Icon,
            map: new Map([
                ["text", enumerations_1.ClassDiagramMemberVisibilityStyle.Text],
                ["icon", enumerations_1.ClassDiagramMemberVisibilityStyle.Icon],
            ]),
            value: enumerations_1.ClassDiagramMemberVisibilityStyle.Icon,
        };
        /**
         * Specifies whether to hide the circled character in front of class names in the class diagrams.
         */
        this.umlClassDiagramHideCircledCharOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideCircledChar",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether to hide the shadowing in the class diagrams. */
        this.umlClassDiagramHideShadowOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideShadow",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies the background color used for boxes in the class diagrams. */
        this.umlClassDiagramBoxBackgroundColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramBoxBackgroundColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the border color used for boxes in the class diagrams. */
        this.umlClassDiagramBoxBorderColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramBoxBorderColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the border radius used for boxes in the class diagrams. */
        this.umlClassDiagramBoxBorderRadiusOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramBoxBorderRadius",
            help: "The box border radius in pixel used for the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the border width used for boxes in the class diagrams. */
        this.umlClassDiagramBoxBorderWidthOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramBoxBorderWidth",
            help: "The box border width in pixel used for the class diagrams.",
            defaultValue: -1,
            minValue: 0,
            value: -1,
        };
        /** Specifies the color used for arrows in the class diagrams. */
        this.umlClassDiagramArrowColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramArrowColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the name of the font used for the class name in the class diagrams. */
        this.umlClassDiagramClassFontNameOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassFontName",
            help: "The name of the font used for the class name in the class diagrams.",
            defaultValue: "",
            value: "",
        };
        /** Specifies the font size for the class name in the class diagrams. */
        this.umlClassDiagramClassFontSizeOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramClassFontSize",
            help: "The font size in pixel used for the class name in the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the font style for the class name in the class diagrams. */
        this.umlClassDiagramClassFontStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramClassFontStyle",
            help: "normal|plain|italic|bold",
            defaultValue: "" /* Undefined */,
            map: new Map([
                ["normal", "normal" /* Normal */],
                ["plain", "plain" /* Plain */],
                ["italic", "italic" /* Italic */],
                ["bold", "bold" /* Bold */],
            ]),
            value: "" /* Undefined */,
        };
        /** Specifies the font color for the class name in the class diagrams. */
        this.umlClassDiagramClassFontColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassFontColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the name of the font used for the class attributes in the class diagrams. */
        this.umlClassDiagramClassAttributeFontNameOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassAttributeFontName",
            help: "The name of the font used for the class attributes in the class diagrams.",
            defaultValue: "",
            value: "",
        };
        /** Specifies the font size for the class attributes in the class diagrams. */
        this.umlClassDiagramClassAttributeFontSizeOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramClassAttributeFontSize",
            help: "The font size in pixel used for the class attributes in the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the font style for the class attributes in the class diagrams. */
        this.umlClassDiagramClassAttributeFontStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramClassAttributeFontStyle",
            help: "normal|plain|italic|bold",
            defaultValue: "" /* Undefined */,
            map: new Map([
                ["normal", "normal" /* Normal */],
                ["plain", "plain" /* Plain */],
                ["italic", "italic" /* Italic */],
                ["bold", "bold" /* Bold */],
            ]),
            value: "" /* Undefined */,
        };
        /** Specifies the font color for the class attributes in the class diagrams. */
        this.umlClassDiagramClassAttributeFontColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassAttributeFontColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
    }
    /**
     * Adds the command line options of the plugin to the TypeDoc application.
     * @param typedoc The TypeDoc application.
     */
    // prettier-ignore
    PluginOptions.prototype.addToApplication = function (typedoc) {
        typedoc.options.addDeclaration(this.umlClassDiagramTypeOption);
        typedoc.options.addDeclaration(this.outputImageLocationOption);
        typedoc.options.addDeclaration(this.outputImageFormatOption);
        typedoc.options.addDeclaration(this.umlClassDiagramMethodParameterOutputOption);
        typedoc.options.addDeclaration(this.umlClassDiagramSectionTitleOption);
        typedoc.options.addDeclaration(this.umlClassDiagramPositionOption);
        typedoc.options.addDeclaration(this.umlClassDiagramHideEmptyMembersOption);
        typedoc.options.addDeclaration(this.umlClassDiagramTopDownLayoutMaxSiblingsOption);
        typedoc.options.addDeclaration(this.umlClassDiagramMemberVisibilityStyleOption);
        typedoc.options.addDeclaration(this.umlClassDiagramHideCircledCharOption);
        typedoc.options.addDeclaration(this.umlClassDiagramHideShadowOption);
        typedoc.options.addDeclaration(this.umlClassDiagramBoxBackgroundColorOption);
        typedoc.options.addDeclaration(this.umlClassDiagramBoxBorderColorOption);
        typedoc.options.addDeclaration(this.umlClassDiagramBoxBorderRadiusOption);
        typedoc.options.addDeclaration(this.umlClassDiagramBoxBorderWidthOption);
        typedoc.options.addDeclaration(this.umlClassDiagramArrowColorOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassFontNameOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassFontSizeOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassFontStyleOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassFontColorOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassAttributeFontNameOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassAttributeFontSizeOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassAttributeFontStyleOption);
        typedoc.options.addDeclaration(this.umlClassDiagramClassAttributeFontColorOption);
    };
    /**
     * Reads the values of the plugin options from the application options.
     * @param appOptions The TypeDoc application.
     */
    // prettier-ignore
    PluginOptions.prototype.readValuesFromApplication = function (typedoc) {
        this.umlClassDiagramTypeOption.value = typedoc.options.getValue(this.umlClassDiagramTypeOption.name);
        this.outputImageLocationOption.value = typedoc.options.getValue(this.outputImageLocationOption.name);
        this.outputImageFormatOption.value = typedoc.options.getValue(this.outputImageFormatOption.name);
        this.umlClassDiagramMethodParameterOutputOption.value = typedoc.options.getValue(this.umlClassDiagramMethodParameterOutputOption.name);
        this.umlClassDiagramSectionTitleOption.value = typedoc.options.getValue(this.umlClassDiagramSectionTitleOption.name);
        this.umlClassDiagramPositionOption.value = typedoc.options.getValue(this.umlClassDiagramPositionOption.name);
        this.umlClassDiagramHideEmptyMembersOption.value = typedoc.options.getValue(this.umlClassDiagramHideEmptyMembersOption.name);
        this.umlClassDiagramTopDownLayoutMaxSiblingsOption.value = typedoc.options.getValue(this.umlClassDiagramTopDownLayoutMaxSiblingsOption.name);
        this.umlClassDiagramMemberVisibilityStyleOption.value = typedoc.options.getValue(this.umlClassDiagramMemberVisibilityStyleOption.name);
        this.umlClassDiagramHideCircledCharOption.value = typedoc.options.getValue(this.umlClassDiagramHideCircledCharOption.name);
        this.umlClassDiagramHideShadowOption.value = typedoc.options.getValue(this.umlClassDiagramHideShadowOption.name);
        this.umlClassDiagramBoxBackgroundColorOption.value = typedoc.options.getValue(this.umlClassDiagramBoxBackgroundColorOption.name);
        this.umlClassDiagramBoxBorderColorOption.value = typedoc.options.getValue(this.umlClassDiagramBoxBorderColorOption.name);
        this.umlClassDiagramBoxBorderRadiusOption.value = typedoc.options.getValue(this.umlClassDiagramBoxBorderRadiusOption.name);
        this.umlClassDiagramBoxBorderWidthOption.value = typedoc.options.getValue(this.umlClassDiagramBoxBorderWidthOption.name);
        this.umlClassDiagramArrowColorOption.value = typedoc.options.getValue(this.umlClassDiagramArrowColorOption.name);
        this.umlClassDiagramClassFontNameOption.value = typedoc.options.getValue(this.umlClassDiagramClassFontNameOption.name);
        this.umlClassDiagramClassFontSizeOption.value = typedoc.options.getValue(this.umlClassDiagramClassFontSizeOption.name);
        this.umlClassDiagramClassFontStyleOption.value = typedoc.options.getValue(this.umlClassDiagramClassFontStyleOption.name);
        this.umlClassDiagramClassFontColorOption.value = typedoc.options.getValue(this.umlClassDiagramClassFontColorOption.name);
        this.umlClassDiagramClassAttributeFontNameOption.value = typedoc.options.getValue(this.umlClassDiagramClassAttributeFontNameOption.name);
        this.umlClassDiagramClassAttributeFontSizeOption.value = typedoc.options.getValue(this.umlClassDiagramClassAttributeFontSizeOption.name);
        this.umlClassDiagramClassAttributeFontStyleOption.value = typedoc.options.getValue(this.umlClassDiagramClassAttributeFontStyleOption.name);
        this.umlClassDiagramClassAttributeFontColorOption.value = typedoc.options.getValue(this.umlClassDiagramClassAttributeFontColorOption.name);
    };
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramType", {
        /**
         * Returns how detailed the generated class diagrams should be.
         * @returns How detailed the generated class diagrams should be.
         */
        get: function () {
            return this.umlClassDiagramTypeOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "outputImageLocation", {
        /**
         * Returns the location where the class diagrams should be stored.
         * @returns The location where the class diagrams should be stored.
         */
        get: function () {
            return this.outputImageLocationOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "outputImageFormat", {
        /**
         * Returns the image format used for the class diagrams.
         * @returns The image format used for the class diagrams.
         */
        get: function () {
            return this.outputImageFormatOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramMethodParameterOutput", {
        /**
         * Returns how method parameters should be output in the class diagrams.
         * @returns How method parameters should be output in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramMethodParameterOutputOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramSectionTitle", {
        /**
         * Returns the title that should be used for the section that contains the class diagrams.
         * @returns The title that should be used for the section that contains the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramSectionTitleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramPosition", {
        /**
         * Returns where on the page the class diagrams should be put.
         * @returns Where on the page the class diagrams should be put.
         */
        get: function () {
            return this.umlClassDiagramPositionOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramHideEmptyMembers", {
        /**
         * Returns whether to hide empty properties and methods in the class diagrams.
         * @returns Whether to hide empty properties and methods in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramHideEmptyMembersOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramTopDownLayoutMaxSiblings", {
        /**
         * Returns the boundary before swiching from top->down to left->right direction for class diagrams.
         * @returns The boundary before swiching from top->down to left->right direction for class diagrams.
         */
        get: function () {
            return this.umlClassDiagramTopDownLayoutMaxSiblingsOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramMemberVisibilityStyle", {
        /**
         * Returns how the member visibility is rendered in the class diagrams.
         * @returns How the member visibility is rendered in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramMemberVisibilityStyleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramHideCircledChar", {
        /**
         * Returns whether to hide the circled character in front of class names for class diagrams.
         * @returns Whether to hide the circled character in front of class names for class diagrams.
         */
        get: function () {
            return this.umlClassDiagramHideCircledCharOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramHideShadow", {
        /**
         * Returns whether to hide the shadows in the class diagrams.
         * @returns Whether to hide the shadows in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramHideShadowOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramBoxBackgroundColor", {
        /**
         * Returns the background color that should be used for boxes in the class diagrams.
         * @returns The background color that should be used for boxes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramBoxBackgroundColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramBoxBorderColor", {
        /**
         * Returns the border color that should be used for boxes in the class diagrams.
         * @returns The border color that should be used for boxes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramBoxBorderColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramBoxBorderRadius", {
        /**
         * Returns the border radius that should be used for boxes in the class diagrams.
         * @returns The border radius that should be used for boxes in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramBoxBorderRadiusOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramBoxBorderWidth", {
        /**
         * Returns the border width that should be used for boxes in the class diagrams.
         * @returns The border width that should be used for boxes in the class diagrams.
         *          The value -1 if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramBoxBorderWidthOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramArrowColor", {
        /**
         * Returns the color that should be used for arrows in the class diagrams.
         * @returns The color that should be used for arrows in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramArrowColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassFontName", {
        /**
         * Returns the name of the font that should be used for the class name in the class diagrams.
         * @returns The name of the font that should be used for the class name in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramClassFontNameOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassFontSize", {
        /**
         * Returns the font size that should be used for class names in the class diagrams.
         * @returns The font size that should be used for class names in the class diagrams.
         *          The value 0 if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramClassFontSizeOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassFontStyle", {
        /**
         * Returns the font style that should be used for the class name in the class diagrams.
         * @returns The font style that should be used for the class name in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramClassFontStyleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassFontColor", {
        /**
         * Returns the font color that should be used for the class name in the class diagrams.
         * @returns The font color that should be used for the class name in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramClassFontColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassAttributeFontName", {
        /**
         * Returns the name of the font that should be used for class attributes in the class diagrams.
         * @returns The name of the font that should be used for class attributes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramClassAttributeFontNameOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassAttributeFontSize", {
        /**
         * Returns the font size that should be used for class attributes in the class diagrams.
         * @returns The font size that should be used for class attributes in the class diagrams.
         *          The value 0 if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramClassAttributeFontSizeOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassAttributeFontStyle", {
        /**
         * Returns the font style that should be used for the class attributes in the class diagrams.
         * @returns The font style that should be used for the class attributes in the class diagrams.
         */
        get: function () {
            return this.umlClassDiagramClassAttributeFontStyleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "umlClassDiagramClassAttributeFontColor", {
        /**
         * Returns the font color that should be used for the class attributes in the class diagrams.
         * @returns The font color that should be used for the class attributes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.umlClassDiagramClassAttributeFontColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    return PluginOptions;
}());
exports.PluginOptions = PluginOptions;
